pub(crate) async fn run(
pool: &PgPool,
scope: &RegistrationScope,
base_url: &str,
) -> CreditRegistrationResult<Counts>Expand description
base_url is the absolute base for the mail’s link, which outlives the process that wrote it.
pub(crate) async fn run(
pool: &PgPool,
scope: &RegistrationScope,
base_url: &str,
) -> CreditRegistrationResult<Counts>base_url is the absolute base for the mail’s link, which outlives the process that wrote it.